#!/usr/bin/python
from bs4 import BeautifulSoup as BS
import json
import os
import base64

CONFIG_FILE = "config.json"
TEMPLATE_FILE = "template.html"
SUBMISSION_FILE = "submission.html"
REF_DIR = "refs/"

def build_submission(data):
    # Load template file
    with open(TEMPLATE_FILE) as inf:
        txt = inf.read()
        soup = BS(txt, "html5lib")

    # Set assignment number
    assignment = soup.find(id="assignment")
    assignment.append(" " + str(data["assignment-number"]))

    # Set student name and HTML title
    name = soup.find(id="name")
    name.clear()
    name.append(data["firstname-lastname"])

    # Set student ID
    id = soup.find(id="id")
    id.clear()
    id.append("#" + str(data["student-id"]))

    # Set HTML title
    title = soup.find("title")
    title.clear()
    title.append(data["firstname-lastname"] + " | #" + str(data["student-id"]))

    # Set read me, if any
    readme = soup.find(id="read-me")
    if data["read-me"]:
        note = soup.find(id="read-me-content")
        note.clear()
        note.append(str(data["read-me"]))
    else:
        readme.clear()

    # Set references, if any
    references = soup.find(id="references")
    if data["references"]:
        refs = soup.find(id="references-content")
        refs.clear()
        refs.append(str(data["references"]))
    else:
        references.clear()

    # Add rendered images
    renders = soup.find(id="renders")
    dir = str(data["img-dir"])
    for idx, img in enumerate(os.listdir(dir)):
        if img.endswith(".png"):
            with open(dir + img, "rb") as imgf:
                scene  = "<h3>Scene " + str(idx) + "</h3>" + '\n' 
                scene += "<div class='twentytwenty-container'>" + '\n'
                scene += "<img alt='Reference' class='reference' src='" + REF_DIR + str(idx) + ".png'/>" + '\n'
                scene += "<img alt='Final' src='data:image/png;base64,"
                scene += str(base64.b64encode(imgf.read())) + "'/>"
                scene += "</div>" + '\n'
                renders.append(BS(scene, "html.parser"))
                print(dir + img + " added to template")
               
    #soup.prettify()

    # Write submission
    with open(SUBMISSION_FILE, "w") as outf:
        outf.write(str(soup))

    # Echo
    print("Assignment " + str(data["assignment-number"]) + " (" + SUBMISSION_FILE + ") " + "successfully built!")

if __name__ == "__main__":
    with open(CONFIG_FILE) as cf:    
        data = json.load(cf)
    build_submission(data)
